#ifndef QFLEXIMON_HH
#define QFLEXIMON_HH

//
// QFleximon - Qt program to monitor fleximon daemons.
//
// This program is part of Fleximon, a flexible, plugin-based client-server
// monitoring framework.
//
// See http://fleximon.sourceforge.net for details.
//
// 2002, Patrick Schemitz <schemitz@users.sourceforge.net>
//

#include <netinet/in.h>
#include <vector>
using std::vector;

class QCheckBox;
class QLineEdit;
class QGridLayout;
class QLabel;
class QPopupMenu;
class QTimer;
#include <qpixmap.h>
#include <qiconview.h>
#include <qmainwindow.h>
#include <qdatastream.h>


class QFlexiHost : public QIconViewItem {
public:
    QFlexiHost (QIconView* parent, QString hostname, unsigned port);
    ~QFlexiHost ();
    QFlexiHost* clone () const;
    QString ipString () const;
    void lookupHost ();
    void updateHost (bool force = false);
    void configure ();
private:
    static const unsigned DelayOnError = 5;
    friend class QFlexiPluginConfig;
    friend class QFlexiHostStatus;
    friend class QFlexiHostEdit;
    friend QDataStream& operator<< (QDataStream&, const QFlexiHost&);
    friend QDataStream& operator>> (QDataStream&, QFlexiHost&);
    bool fmGetList ();
    bool fmGetValues ();
    QPixmap pic;
    QString hostname;
    unsigned port;
    in_addr_t ip;
    int delay;
    struct Plugin {
	QString name;
	QString desc;
	QString args;
	QString value;
	bool use;
    };
    vector<Plugin> plugin;
};


class QFlexiPluginConfig : public QWidget {
    Q_OBJECT
public:
    QFlexiPluginConfig (QFlexiHost* host, QWidget* parent = 0);
    ~QFlexiPluginConfig ();
public slots:
    void apply ();
private:
    QFlexiHost* host;
    unsigned n;
    QCheckBox** checkbox;
    QLineEdit** arg;
};


class QFlexiHostStatus : public QWidget {
    Q_OBJECT
public:
    QFlexiHostStatus (QFlexiHost* host, QWidget* parent = 0);
    ~QFlexiHostStatus ();
public slots:
    void apply ();
private:
    QFlexiHost* host;
    unsigned n;
    QGridLayout* grid;
    QLabel** command;
    QLabel** value;
};


class QFlexiHostEdit : public QWidget {
    Q_OBJECT
public:
    QFlexiHostEdit (QFlexiHost* host, QWidget* parent = 0);
    ~QFlexiHostEdit ();
public slots:
    void apply ();
private:
    QFlexiHost* host;
    QLineEdit* hostName;
    QLineEdit* hostPort;
    QLabel* hostIP;
};


class QFlexiWindow : public QMainWindow {
    Q_OBJECT
public:
    QFlexiWindow (QWidget* parent = 0);
    ~QFlexiWindow ();
    QIconView* iconView () const;
private slots:
    void fileOpen ();
    void fileSave ();
    void fileSaveAs ();
    void fileNew ();
    void hostNew ();
    void hostClone ();
    void hostDelete ();
    void hostUpdate ();
    void hostMenu ();
    void hostMenu (QIconViewItem* item, const QPoint& pos);
    void update ();
    void autoUpdate ();
    void toggleAutoUpdate ();
    void configUpdateInterval ();
    void about ();
    void aboutQt ();
private:
    static const unsigned UpdateTimerInterval = 200;
    unsigned updateInterval;
    QTimer* timer;
    QPopupMenu* updateMenu;
    int idAutoUpdate;
    bool hostlistChanged;
    QIconView* iv;
    QString filename;
};

#endif
